==> ejc-ztpcdc-impl-3.0.0-20230505.055326-10-sources.jar: com/ejianc/business/dc/bean/DcDrawdistributeDrwgrpinfoEntity.java <==
package com.ejianc.business.dc.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 卷册签发信息
 * 
 * @author generator
 * 
 */
 @TableName("dc_drawdistribute_drwgrpinfo")
public class DcDrawdistributeDrwgrpinfoEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="pid")
    private Long pid; // 图纸分发表主键id
    @TableField(value="order_num")
    private Integer orderNum; // 顺序号
    @TableField(value="drwgrp_code")
    private String drwgrpCode; // 卷册编号
    @TableField(value="drwgrp_name")
    private String drwgrpName; // 卷册名称
    @TableField(value="drwgrp_vsn")
    private String drwgrpVsn; // 卷册版本
    @TableField(value="drwgrp_type")
    private Long drwgrpType; // 图纸类别--字典dc_drwgrp_type
    @TableField(value="num")
    private Integer num; // 份数
    @TableField(value="paper_flag")
    private String paperFlag; // 是否纸质版
    @TableField(value="mgrp")
    private Long mgrp; // 机组--字典pub_mgrp_code
    @TableField(value="specialty")
    private Long specialty; // 专业--字典pub_specialty_code
    @TableField(value="receive_dept_id")
    private Long receiveDeptId; // 接收部门id
    @TableField(value="receive_user_code")
    private String receiveUserCode; // 接收人编号
    @TableField(value="receive_user_name")
    private String receiveUserName; // 接收人姓名
    @TableField(value="recycle_sts")
    private String recycleSts; // 是否回收--字典flag_yn
    @TableField(value="create_dept_id")
    private Long createDeptId; // 创建部门id
    @TableField(value="org_id")
    private Long orgId; // 所属组织id
    @TableField(value="org_code")
    private String orgCode; // 组织编码
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="parent_org_id")
    private Long parentOrgId; // 所属组织
    @TableField(value="parent_org_code")
    private String parentOrgCode; // 所属组织编码
    @TableField(value="parent_org_name")
    private String parentOrgName; // 所属组织名称



    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }
    public Integer getOrderNum() {
        return orderNum;
    }

    public void setOrderNum(Integer orderNum) {
        this.orderNum = orderNum;
    }
    public String getDrwgrpCode() {
        return drwgrpCode;
    }

    public void setDrwgrpCode(String drwgrpCode) {
        this.drwgrpCode = drwgrpCode;
    }
    public String getDrwgrpName() {
        return drwgrpName;
    }

    public void setDrwgrpName(String drwgrpName) {
        this.drwgrpName = drwgrpName;
    }
    public String getDrwgrpVsn() {
        return drwgrpVsn;
    }

    public void setDrwgrpVsn(String drwgrpVsn) {
        this.drwgrpVsn = drwgrpVsn;
    }
    public Long getDrwgrpType() {
        return drwgrpType;
    }

    public void setDrwgrpType(Long drwgrpType) {
        this.drwgrpType = drwgrpType;
    }
    public Integer getNum() {
        return num;
    }

    public void setNum(Integer num) {
        this.num = num;
    }
    public String getPaperFlag() {
        return paperFlag;
    }

    public void setPaperFlag(String paperFlag) {
        this.paperFlag = paperFlag;
    }
    public Long getMgrp() {
        return mgrp;
    }

    public void setMgrp(Long mgrp) {
        this.mgrp = mgrp;
    }
    public Long getSpecialty() {
        return specialty;
    }

    public void setSpecialty(Long specialty) {
        this.specialty = specialty;
    }
    public Long getReceiveDeptId() {
        return receiveDeptId;
    }

    public void setReceiveDeptId(Long receiveDeptId) {
        this.receiveDeptId = receiveDeptId;
    }
    public String getReceiveUserCode() {
        return receiveUserCode;
    }

    public void setReceiveUserCode(String receiveUserCode) {
        this.receiveUserCode = receiveUserCode;
    }
    public String getReceiveUserName() {
        return receiveUserName;
    }

    public void setReceiveUserName(String receiveUserName) {
        this.receiveUserName = receiveUserName;
    }
    public String getRecycleSts() {
        return recycleSts;
    }

    public void setRecycleSts(String recycleSts) {
        this.recycleSts = recycleSts;
    }
    public Long getCreateDeptId() {
        return createDeptId;
    }

    public void setCreateDeptId(Long createDeptId) {
        this.createDeptId = createDeptId;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    
}

==> ejc-ztpcdc-impl-3.0.0-20231221.004858-259-sources.jar: com/ejianc/business/dc/bean/DcDrawdistributeDrwgrpinfoEntity.java <==
package com.ejianc.business.dc.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 卷册签发信息
 * 
 * @author generator
 * 
 */
 @TableName("dc_drawdistribute_drwgrpinfo")
public class DcDrawdistributeDrwgrpinfoEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="pid")
    private Long pid; // 图纸分发表主键id
    @TableField(value="project_id")
    private Long projectId; // 项目ID
    @TableField(value="project_code")
    private String projectCode; // 项目编码
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="order_num")
    private Integer orderNum; // 顺序号
    @TableField(value="drwgrp_id")
    private Long drwgrpId; // 卷册ID
    @TableField(value="drwgrp_code")
    private String drwgrpCode; // 卷册编号
    @TableField(value="drwgrp_name")
    private String drwgrpName; // 卷册名称
    @TableField(value="drwgrp_vsn")
    private String drwgrpVsn; // 卷册版本
    @TableField(value="drwgrp_type")
    private Long drwgrpType; // 图纸类别--字典dc_drwgrp_type
    @TableField(value="num")
    private Integer num; // 份数
    @TableField(value="paper_flag")
    private String paperFlag; // 是否纸质版
    @TableField(value="mgrp")
    private Long mgrp; // 机组--字典pub_mgrp_code
    @TableField(value="specialty")
    private Long specialty; // 专业--字典pub_specialty_code
    @TableField(value="receive_user_id")
    private Long receiveUserId; // 接收人主键id
    @TableField(value="receive_user_code")
    private String receiveUserCode; // 接收人编号
    @TableField(value="receive_user_name")
    private String receiveUserName; // 接收人姓名
    @TableField(value="recycle_sts")
    private String recycleSts; // 是否回收--字典flag_yn
    @TableField(value="create_dept_id")
    private Long createDeptId; // 创建部门id
    @TableField(value="org_id")
    private Long orgId; // 所属组织id
    @TableField(value="org_code")
    private String orgCode; // 组织编码
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="parent_org_id")
    private Long parentOrgId; // 所属组织
    @TableField(value="parent_org_code")
    private String parentOrgCode; // 所属组织编码
    @TableField(value="parent_org_name")
    private String parentOrgName; // 所属组织名称
    @TableField(value="receive_dept_name")
    private String receiveDeptName; // 接收人部门名称

    @TableField(exist = false)
    private List<DcDrawInfoEntity> dcDrawInfoList = new ArrayList<>();

    public List<DcDrawInfoEntity> getDcDrawInfoList() {
        return dcDrawInfoList;
    }

    public void setDcDrawInfoList(List<DcDrawInfoEntity> dcDrawInfoList) {
        this.dcDrawInfoList = dcDrawInfoList;
    }

    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }
    public Integer getOrderNum() {
        return orderNum;
    }

    public void setOrderNum(Integer orderNum) {
        this.orderNum = orderNum;
    }
    public String getDrwgrpCode() {
        return drwgrpCode;
    }

    public void setDrwgrpCode(String drwgrpCode) {
        this.drwgrpCode = drwgrpCode;
    }
    public String getDrwgrpName() {
        return drwgrpName;
    }

    public void setDrwgrpName(String drwgrpName) {
        this.drwgrpName = drwgrpName;
    }
    public String getDrwgrpVsn() {
        return drwgrpVsn;
    }

    public void setDrwgrpVsn(String drwgrpVsn) {
        this.drwgrpVsn = drwgrpVsn;
    }
    public Long getDrwgrpType() {
        return drwgrpType;
    }

    public void setDrwgrpType(Long drwgrpType) {
        this.drwgrpType = drwgrpType;
    }
    public Integer getNum() {
        return num;
    }

    public void setNum(Integer num) {
        this.num = num;
    }
    public String getPaperFlag() {
        return paperFlag;
    }

    public void setPaperFlag(String paperFlag) {
        this.paperFlag = paperFlag;
    }
    public Long getMgrp() {
        return mgrp;
    }

    public void setMgrp(Long mgrp) {
        this.mgrp = mgrp;
    }
    public Long getSpecialty() {
        return specialty;
    }

    public void setSpecialty(Long specialty) {
        this.specialty = specialty;
    }
    public String getReceiveUserCode() {
        return receiveUserCode;
    }

    public void setReceiveUserCode(String receiveUserCode) {
        this.receiveUserCode = receiveUserCode;
    }
    public String getReceiveUserName() {
        return receiveUserName;
    }

    public void setReceiveUserName(String receiveUserName) {
        this.receiveUserName = receiveUserName;
    }
    public String getRecycleSts() {
        return recycleSts;
    }

    public void setRecycleSts(String recycleSts) {
        this.recycleSts = recycleSts;
    }
    public Long getCreateDeptId() {
        return createDeptId;
    }

    public void setCreateDeptId(Long createDeptId) {
        this.createDeptId = createDeptId;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public String getReceiveDeptName() {
        return receiveDeptName;
    }

    public void setReceiveDeptName(String receiveDeptName) {
        this.receiveDeptName = receiveDeptName;
    }

    public Long getReceiveUserId() {
        return receiveUserId;
    }

    public void setReceiveUserId(Long receiveUserId) {
        this.receiveUserId = receiveUserId;
    }

    public Long getDrwgrpId() {
        return drwgrpId;
    }

    public void setDrwgrpId(Long drwgrpId) {
        this.drwgrpId = drwgrpId;
    }
}
